@@ -27,12 +27,15 @@ def main():
         return 2
     last_run_grace = int(opts.last_run_grace)
     warn_duration = int(opts.warn_duration)
-    if not os.path.exists(args[0]):
+    filename = args[0]
+    if not os.path.exists(filename):
         sys.stdout.write(
-            "No such file or directory: %s, has submit-for-packaging ever run?")
+            "No such file or directory: %s, has submit-for-packaging ever run?"
+            % (filename,))
         return 2
-    with open(args[0]) as f:
+    with open(filename) as f:
         output = f.read()
-    result, message = check_saved_output(output, last_run_grace, warn_duration)
+    result, message = check_saved_output(
+        output, last_run_grace, warn_duration, filename)
     sys.stdout.write(message + '\n')
     return result
